extensions [ gis ]

Breed [Persons Person]

globals
[
  elapsed-day-hours
  elapsed-week-days
  medical_care_used
  number_of_deaths
  cumulative_aware_of_infection
  logged_transmitters
  cumulative_infected
  change_lockdown_condition?
  R0_global
  daily_new_cases
  daily_new_deaths
  Deaths_by_age_0_4
  Deaths_by_age_5_9
  Deaths_by_age_10_14
  Deaths_by_age_15_19
  Deaths_by_age_20_24
  Deaths_by_age_25_29
  Deaths_by_age_30_34
  Deaths_by_age_35_39
  Deaths_by_age_40_44
  Deaths_by_age_45_49
  Deaths_by_age_50_54
  Deaths_by_age_55_59
  Deaths_by_age_60_64
  Deaths_by_age_65_69
  Deaths_by_age_70_74
  Deaths_by_age_75+
  DEM
  Region
  Neighborhoods
  Pobulation_Blocks
  Educational_facilities
  Commercial_facilities
  Cultural_and_sports_facilities
  Government_facilities
  Health_facilities
  Religious_facilities
  Kindergarten_patches
  Primary_school_patches
  Middle_school_patches
  Secondary_school_patches
  University_patches
  Residential_patches
  Educational_patches
  Commercial_patches
  Cultural_patches
  Government_patches
  Health_patches
  Religious_patches
  Risk_of_Residential
  Risk_of_Educational
  Risk_of_Commercial
  Risk_of_Cultural
  Risk_of_Government
  Risk_of_Health
  Risk_of_Religious
]

patches-own
[
  Extent
  Patch_ID
  Risk
  Residential
  Educational
  Commercial
  Cultural
  Government
  Health
  Religious
]

Persons-own
[
  infected?
  infection-length
  aggravated_symptoms_day
  ontreatment?
  gotinfection?
  contagion-chance
  death-chance
  ongoing-infection-hours
  symptoms_delay
  aware_of_infection?
  Age
  Gender
  Id
  Neighbourhood_ID
  Exit?
]

to-report calculate_R0
  let list_of_transmitters remove-duplicates logged_transmitters
  let current_case 0
  let sum_repetitions 0
  foreach list_of_transmitters
  [
    patient -> set current_case patient
    let transmitter_repeated length filter [ i -> i = current_case] logged_transmitters
    set sum_repetitions sum_repetitions + transmitter_repeated
  ]
  ifelse length list_of_transmitters > 0
  [
    report sum_repetitions / ( length list_of_transmitters )
  ]
  [
    report 0
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;   HUMANS PROCEDURES   ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report persons-at-moore-neighborhood
  report Persons at-points [[-1 1] [1 1] [-1 -1] [-1 0] [1 0] [0 1] [0 0] [0 -1] [1 -1]]
end

to-report patches-at-moore-neighborhood
  report Patches at-points [[-1 1] [1 1] [-1 -1] [-1 0] [1 0] [0 1] [0 -1] [1 -1]]
end

to infection_exposure
  if (not gotinfection?)
  [
    let people_around persons-at-moore-neighborhood
    let infected_around people_around with [infected? = true and not ontreatment? and ( ongoing-infection-hours > (average_days_for_contagion * 24)) ]
    let number_of_infected_around count infected_around
    if number_of_infected_around > 0
    [
      let within_contagion_distance ((random metres_per_patch) + 1) ;; Assuming each patch represents up to metres_per_patch distance units (meters)
      set within_contagion_distance within_contagion_distance + random-float ( keep_social_distancing ) ;; Assuming the ordered social distance is not followed accurately but more randomly and proportionate to the ordered distance
      ;;;;;;;;; Chance of Contagion according to age group:
      if (contagion-chance >= (random-float 100) and within_contagion_distance <= maximum_contagion_distance)
      [
        let transmitter_person nobody
        ask one-of infected_around [ set transmitter_person who ]
        set logged_transmitters lput transmitter_person logged_transmitters
        ;  if length ( logged_transmitters ) > 800[ ;;Do not allow the list to grow without end, delete older elements.
        ;   set logged_transmitters but-first logged_transmitters
        ;  ]

        get_infected

        set daily_new_cases daily_new_cases + 1

        ask patch-here [
          set Risk Risk + 1
          if (Residential = "Residential") [set Risk_of_Residential Risk_of_Residential + 1]
          if (Educational = "Kindergarten" or Educational = "Primary school" or Educational = "Middle school" or Educational = "Secondary school" or Educational = "University") [set Risk_of_Educational Risk_of_Educational + 1]
          if (Commercial = "Commercial") [set Risk_of_Commercial Risk_of_Commercial + 1]
          if (Cultural = "Cultural") [set Risk_of_Cultural Risk_of_Cultural + 1]
          if (Government = "Government") [set Risk_of_Government Risk_of_Government + 1]
          if (Health = "Health") [set Risk_of_Health Risk_of_Health + 1]
          if (Religious = "Religious") [set Risk_of_Religious Risk_of_Religious + 1]
        ]
      ]
    ]
  ]
end

to get_infected
  set color red
  set infected? true
  set gotinfection? true
  set infection-length 24 * ( random-normal average_infection_length 5.0 ) ;; mean of infection length and standard-deviation multiplied by 24 hours
  set aggravated_symptoms_day round (infection-length / 2.5) ;; Aggravated infection may happen after the first week
  set symptoms_delay 24 * ( random-normal average-symptoms-show 4.0 )
  set ongoing-infection-hours 0
  set cumulative_infected cumulative_infected + 1
end

to get-healthy
  set infected? false
  set gotinfection? true
  set color green
  set aware_of_infection? false
  set infection-length 0
  set ongoing-infection-hours 0
  set aggravated_symptoms_day 0
  if ontreatment?
  [
    free-medical-care
    set ontreatment? false
  ]

  ;update-recovered-statistics age-group
end

to check_health_state
  if infected?
  [
    if ongoing-infection-hours >= ( symptoms_delay + random(diagnosis_delay) ) and not ontreatment?
    [
      if not aware_of_infection?
      [
        set aware_of_infection? true
        set cumulative_aware_of_infection cumulative_aware_of_infection + 1
      ]
      ifelse prioritise_elderly?
      [
        ifelse Age >= 60
        [
          if get-medical-care = true
          [
            set ontreatment? true
          ]
        ]
        [
          if %medical-care-availability >= 25
          [ ;;If not an elderly person then only take medical care if availability >= 25%
            if get-medical-care = true
            [
              set ontreatment? true
            ]
          ]
        ]
      ]
      [
        if get-medical-care = true
        [
          set ontreatment? true
        ]
      ]
    ]
    if (ongoing-infection-hours = aggravated_symptoms_day) ;;Check if patient is going to die
    [
      ;;;;;;;;;; Decide if patient survived or not the infection:
      let chance_to_die 0
      let severity_factor 1
      if ( ( chance_of_severe_infection * 1000 ) >= random(100000) )
      [ ;;Patient got a severe infection increasing the death chance by a severity factor
        set severity_factor severity_death_chance_multiplier
      ]
      ifelse (ontreatment?)
      [
        set chance_to_die ((death-chance * 1000) * severity_factor) * 0.5 ;; Death chance is reduced to 50%, Survival chance is increased by 50%
      ]
      [
        set chance_to_die (death-chance * 1000) * severity_factor
      ]

      if (chance_to_die >= (random(100000) + 1))
      [
        ;update-death-statistics age-group
        set number_of_deaths number_of_deaths + 1
        set daily_new_deaths daily_new_deaths + 1

        if (Age <= 4) [ set Deaths_by_age_0_4 Deaths_by_age_0_4 + 1 ]
        if (Age >= 5 and Age <= 9) [ set Deaths_by_age_5_9 Deaths_by_age_5_9 + 1 ]
        if (Age >= 10 and Age <= 14) [ set Deaths_by_age_10_14 Deaths_by_age_10_14 + 1 ]
        if (Age >= 15 and Age <= 19) [ set Deaths_by_age_15_19 Deaths_by_age_15_19 + 1 ]
        if (Age >= 20 and Age <= 24) [ set Deaths_by_age_20_24 Deaths_by_age_20_24 + 1 ]
        if (Age >= 25 and Age <= 29) [ set Deaths_by_age_25_29 Deaths_by_age_25_29 + 1 ]
        if (Age >= 30 and Age <= 34) [ set Deaths_by_age_30_34 Deaths_by_age_30_34 + 1 ]
        if (Age >= 35 and Age <= 39) [ set Deaths_by_age_35_39 Deaths_by_age_35_39 + 1 ]
        if (Age >= 40 and Age <= 44) [ set Deaths_by_age_40_44 Deaths_by_age_40_44 + 1 ]
        if (Age >= 45 and Age <= 49) [ set Deaths_by_age_45_49 Deaths_by_age_45_49 + 1 ]
        if (Age >= 50 and Age <= 54) [ set Deaths_by_age_50_54 Deaths_by_age_50_54 + 1 ]
        if (Age >= 55 and Age <= 59) [ set Deaths_by_age_55_59 Deaths_by_age_55_59 + 1 ]
        if (Age >= 60 and Age <= 64) [ set Deaths_by_age_60_64 Deaths_by_age_60_64 + 1 ]
        if (Age >= 65 and Age <= 69) [ set Deaths_by_age_65_69 Deaths_by_age_65_69 + 1 ]
        if (Age >= 70 and Age <= 74) [ set Deaths_by_age_70_74 Deaths_by_age_70_74 + 1 ]
        if (Age >= 75) [ set Deaths_by_age_75+ Deaths_by_age_75+ + 1 ]

        delete-person
      ]
    ]

    ifelse (ongoing-infection-hours >= infection-length)
    [
      set ongoing-infection-hours 0
      get-healthy
    ]
    [
      set ongoing-infection-hours ongoing-infection-hours + 1
    ]
  ]
end

to move [ #speed ]
  if not ontreatment?
  [
    let sum-patches-at-neighbors count patches-at-moore-neighborhood with [ Extent = "Yes" ]
    ifelse sum-patches-at-neighbors = 8
    [
      rt random-float 360
      fd #speed
    ]
    [
      move-to one-of patches-at-moore-neighborhood with [ Extent = "Yes" ]
    ]
  ]
end

to delete-person
  if ontreatment?
  [
    free-medical-care
  ]
  die
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;   Disply maps   ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to display-Region

gis:set-drawing-color white gis:draw Region 1

end

to display-Neighborhoods

gis:set-drawing-color brown gis:fill Neighborhoods 2

end

to display-Pobulation_Blocks

gis:set-drawing-color yellow gis:fill Pobulation_Blocks 2

end

to display-DEM

  gis:paint DEM 1

end
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;   SETUP PROCEDURES   ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to setup

  __clear-all-and-reset-ticks

  gis:load-coordinate-system "Dataset/Region.prj"

  set DEM gis:load-dataset "Dataset/dem.asc"
  set Region gis:load-dataset "Dataset/Region.shp"
  set Neighborhoods gis:load-dataset "Dataset/Mahallat.shp"
  set Pobulation_Blocks gis:load-dataset "Dataset/Residential_blocks.shp"
  set Educational_facilities gis:load-dataset "Dataset/Educational facilities.shp"
  set Commercial_facilities gis:load-dataset "Dataset/Commercial_facilities.shp"
  set Cultural_and_sports_facilities gis:load-dataset "Dataset/Cultural_and_sports_facilities1.shp"
  set Government_facilities gis:load-dataset "Dataset/Government_facilities.shp"
  set Health_facilities gis:load-dataset "Dataset/Health_facilities.shp"
  set Religious_facilities gis:load-dataset "Dataset/Religious_facilities.shp"


  gis:set-world-envelope (gis:envelope-union-of
                                                 (gis:envelope-of DEM)
                                                 (gis:envelope-of Region)
                                                 (gis:envelope-of Neighborhoods)
                                                 (gis:envelope-of Pobulation_Blocks)
                                                 (gis:envelope-of Educational_facilities)
                                                 (gis:envelope-of Commercial_facilities)
                                                 (gis:envelope-of Cultural_and_sports_facilities)
                                                 (gis:envelope-of Government_facilities)
                                                 (gis:envelope-of Health_facilities)
                                                 (gis:envelope-of Religious_facilities))

  resize-world 0 (gis:width-of DEM - 1) 0 (gis:height-of DEM - 1)

  gis:apply-coverage Region "STATUS" Extent
  gis:apply-coverage Pobulation_Blocks "BOLC" Patch_ID
  gis:apply-coverage Pobulation_Blocks "RESIDENT" Residential
  gis:apply-coverage Educational_facilities "FCLASS" Educational
  gis:apply-coverage Commercial_facilities "COMMERCIAL" Commercial
  gis:apply-coverage Cultural_and_sports_facilities "CULTURAL" Cultural
  gis:apply-coverage Government_facilities "GOVERNMENT" Government
  gis:apply-coverage Health_facilities "HEALTH" Health
  gis:apply-coverage Religious_facilities "RELIGIOUS" Religious

  set elapsed-day-hours 0
  set elapsed-week-days 1
  set medical_care_used 0
  set number_of_deaths 0
  set cumulative_infected 0
  set complete_lockdown? false
  set change_lockdown_condition? false
  set prioritise_elderly? false
  set partial_lockdown? false
  set cumulative_aware_of_infection 0
  set logged_transmitters[]
  set R0_global 0

  set Risk_of_Residential 0
  set Risk_of_Educational 0
  set Risk_of_Commercial 0
  set Risk_of_Cultural 0
  set Risk_of_Government 0
  set Risk_of_Health 0
  set Risk_of_Religious 0

  set Deaths_by_age_0_4 0
  set Deaths_by_age_5_9 0
  set Deaths_by_age_10_14 0
  set Deaths_by_age_15_19 0
  set Deaths_by_age_20_24 0
  set Deaths_by_age_25_29 0
  set Deaths_by_age_30_34 0
  set Deaths_by_age_35_39 0
  set Deaths_by_age_40_44 0
  set Deaths_by_age_45_49 0
  set Deaths_by_age_50_54 0
  set Deaths_by_age_55_59 0
  set Deaths_by_age_60_64 0
  set Deaths_by_age_65_69 0
  set Deaths_by_age_70_74 0
  set Deaths_by_age_75+ 0

  set Kindergarten_patches patches with [ Educational = "Kindergarten" ]
  set Primary_school_patches patches with [ Educational = "Primary school" ]
  set Middle_school_patches patches with [ Educational = "Middle school" ]
  set Secondary_school_patches patches with [ Educational = "Secondary school" ]
  set University_patches patches with [ Educational = "University" ]


  set Residential_patches patches with [ Residential = "Residential" ]
  set Educational_patches patches with [ Educational = "Kindergarten" or Educational = "Primary school" or Educational = "Middle school" or Educational = "Secondary school" or Educational = "University" ]
  set Commercial_patches patches with [ Commercial = "Commercial" ]
  set Cultural_patches patches with [ Cultural = "Cultural" ]
  set Government_patches patches with [ Government = "Government" ]
  set Health_patches patches with [ Health = "Health" ]
  set Religious_patches patches with [ Religious = "Religious" ]

  foreach gis:feature-list-of Pobulation_Blocks
  [ ?1 ->
    let location gis:location-of gis:centroid-of ?1
    if not empty? location
    [
      create-Persons round ((gis:property-value ?1 "M_0_4_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 0 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_0-4
        set death-chance chance_of_death_0-4
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_0_4_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 0 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_0-4
        set death-chance chance_of_death_0-4
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_5_9_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 5 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_5-9
        set death-chance chance_of_death_5-9
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_5_9_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 5 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_5-9
        set death-chance chance_of_death_5-9
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_10_14_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 10 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_10-14
        set death-chance chance_of_death_10-14
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_10_14_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 10 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_10-14
        set death-chance chance_of_death_10-14
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_15_19_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 15 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_15-19
        set death-chance chance_of_death_15-19
        set Exit? false
      ]

       create-Persons round ((gis:property-value ?1 "F_15_19_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 15 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_15-19
        set death-chance chance_of_death_15-19
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_20_24_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 20 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_20-24
        set death-chance chance_of_death_20-24
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_20_24_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 20 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_20-24
        set death-chance chance_of_death_20-24
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_25_29_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 25 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_25-29
        set death-chance chance_of_death_25-29
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_25_29_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 25 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_25-29
        set death-chance chance_of_death_25-29
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_30_34_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 30 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_30-34
        set death-chance chance_of_death_30-34
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_30_34_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 30 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_30-34
        set death-chance chance_of_death_30-34
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_35_39_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 35 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_35-39
        set death-chance chance_of_death_35-39
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_35_39_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 35 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_35-39
        set death-chance chance_of_death_35-39
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_40_44_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 40 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_40-44
        set death-chance chance_of_death_40-44
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_40_44_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 40 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_40-44
        set death-chance chance_of_death_40-44
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_45_49_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 45 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_45-49
        set death-chance chance_of_death_45-49
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_45_49_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 45 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_45-49
        set death-chance chance_of_death_45-49
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_50_54_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 50 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_50-54
        set death-chance chance_of_death_50-54
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_50_54_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 50 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_50-54
        set death-chance chance_of_death_50-54
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_55_60_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 55 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_55-59
        set death-chance chance_of_death_55-59
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_55_60_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 55 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_55-59
        set death-chance chance_of_death_55-59
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_61_64_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 60 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_60-64
        set death-chance chance_of_death_60-64
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_61_64_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 60 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_60-64
        set death-chance chance_of_death_60-64
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_65_70_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 65 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_65-69
        set death-chance chance_of_death_65-69
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_65_70_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 65 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_65-69
        set death-chance chance_of_death_65-69
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_71_74_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 70 + random 5
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_70-74
        set death-chance chance_of_death_70-74
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_71_74_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 70 + random 5
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_70-74
        set death-chance chance_of_death_70-74
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "M_75_95_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 75 + random 21
        set Gender "Male"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_75+
        set death-chance chance_of_death_75+
        set Exit? false
      ]

      create-Persons round ((gis:property-value ?1 "F_75_95_") / 10)
      [
        set shape "Person"
        set xcor item 0 location
        set ycor item 1 location
        set color white
        set Age 75 + random 21
        set Gender "Female"
        set Id gis:property-value ?1 "BOLC"
        set Neighbourhood_ID gis:property-value ?1 "NEIGHB_ID"
        set infected? false
        set aggravated_symptoms_day 0
        set ongoing-infection-hours 0
        set ontreatment? false
        set gotinfection? false
        set symptoms_delay 0
        set aware_of_infection? false
        set contagion-chance chance_of_infection_75+
        set death-chance chance_of_death_75+
        set Exit? false
      ]
    ]
  ]

    let affected_number round (count persons * (initial_infected_population / 100))
    infect_people affected_number

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;   ENVIRONMENT - HUMAN PROCEDURES   ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to infect_people [ affected_number ]
  ask n-of affected_number Persons with [ not gotinfection? ] [ get_infected ]
end

to free-medical-care
  set medical_care_used medical_care_used - 1
end

to-report get-medical-care
  if medical_care_used < medical_care_capacity
  [
    set medical_care_used medical_care_used + 1
    report true
  ]
  report false
end

to-report %medical-care-availability
  report ( (medical_care_capacity - medical_care_used) / medical_care_capacity ) * 100
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;   SOCIAL INTERACTIONS - HUMANS PROCEDURES   ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to gather_in_kindergartens
  if partial_lockdown? [ stop ]
  ;let gatherings_size 50
  repeat active_kindergartens [
    let place_x 0
    let place_y 0
    ask one-of Kindergarten_patches [ set place_x pxcor set place_y pycor]
    ask up-to-n-of Gathering_size persons with [ Age >= 3 and Age <= 6 and not aware_of_infection? ][ set xcor place_x - 1 + random(3) set ycor place_y - 1 + random(3) set Exit? true]
  ]
end

to gather_in_primary_schools
  if partial_lockdown? [ stop ]
  ;let gatherings_size 50
  repeat active_primary_schools [
    let place_x 0
    let place_y 0
    ask one-of Primary_school_patches [ set place_x pxcor set place_y pycor]
    ask up-to-n-of Gathering_size persons with [ Age >= 7 and Age <= 11 and not aware_of_infection? ][ set xcor place_x - 1 + random(3) set ycor place_y - 1 + random(3) set Exit? true]
  ]
end

to gather_in_middle_schools
  if partial_lockdown? [ stop ]
  ;let gatherings_size 50
  repeat active_middle_schools [
    let place_x 0
    let place_y 0
    ask one-of Middle_school_patches [ set place_x pxcor set place_y pycor]
    ask up-to-n-of Gathering_size persons with [ Age >= 12 and Age <= 14 and not aware_of_infection? ][ set xcor place_x - 1 + random(3) set ycor place_y - 1 + random(3) set Exit? true]
  ]
end

to gather_in_secondary_schools
  if partial_lockdown? [ stop ]
  ;let gatherings_size 50
  repeat active_secondary_schools [
    let place_x 0
    let place_y 0
    ask one-of Secondary_school_patches [ set place_x pxcor set place_y pycor]
    ask up-to-n-of Gathering_size persons with [ Age >= 15 and Age <= 18 and not aware_of_infection? ][ set xcor place_x - 1 + random(3) set ycor place_y - 1 + random(3) set Exit? true]
  ]
end

to gather_in_universities
  if partial_lockdown? [ stop ]
  ;let gatherings_size 50
  repeat active_universities [
    let place_x 0
    let place_y 0
    ask one-of University_patches [ set place_x pxcor set place_y pycor]
    ask up-to-n-of Gathering_size persons with [ Age >= 19 and Age <= 24 and not aware_of_infection? ][ set xcor place_x - 1 + random(3) set ycor place_y - 1 + random(3) set Exit? true]
  ]
end

to gather_in_government_facilities
  if partial_lockdown? [ stop ]
  ;let gatherings_size 50
  repeat active_government_facilities [
    let place_x 0
    let place_y 0
    ask one-of Government_patches [ set place_x pxcor set place_y pycor]
    ask up-to-n-of Gathering_size persons with [ Age >= 25 and Age <= 74 and not aware_of_infection? ][ set xcor place_x - 1 + random(3) set ycor place_y - 1 + random(3) set Exit? true]
  ]
end

to gather_in_health_facilities
  ;if partial_lockdown? [ stop ]
  ;let gatherings_size 50
  repeat active_health_facilities [
    let place_x 0
    let place_y 0
    ask one-of Health_patches [ set place_x pxcor set place_y pycor]
    ask up-to-n-of Gathering_size persons with [ Age >= 25 and Age <= 74 and not Exit? and not aware_of_infection? ][ set xcor place_x - 1 + random(3) set ycor place_y - 1 + random(2) set Exit? true]
  ]
end

to gather_in_commercial_facilities_1
  if partial_lockdown? [ stop ]
  ;let gatherings_size 50
  repeat active_Commercial_facilities [
    let place_x 0
    let place_y 0
    ask one-of Commercial_patches [ set place_x pxcor set place_y pycor]
    ask up-to-n-of Gathering_size persons with [ Age >= 25 and Age <= 74 and not Exit? and not aware_of_infection? ][ set xcor place_x - 1 + random(3) set ycor place_y + random(2) set Exit? true]
  ]
end

to gather_in_commercial_facilities_2
  if partial_lockdown? [ stop ]
  ;let gatherings_size 50
  repeat active_Commercial_facilities [
    let place_x 0
    let place_y 0
    ask one-of Commercial_patches [ set place_x pxcor set place_y pycor]
    ask up-to-n-of Gathering_size persons with [ Age >= 3 and Age <= 74 and not Exit? and not aware_of_infection? ][ set xcor place_x - 1 + random(3) set ycor place_y + random(2) set Exit? true]
  ]
end

to gather_in_cultural_facilities
  if partial_lockdown? [ stop ]
  ;let gatherings_size 50
  repeat active_cultural_facilities [
    let place_x 0
    let place_y 0
    ask one-of Cultural_patches [ set place_x pxcor set place_y pycor]
    ask up-to-n-of Gathering_size persons with [ Age >= 3 and Age <= 74 and not Exit? and not aware_of_infection? ][ set xcor place_x set ycor place_y set Exit? true]
  ]
end

to gather_in_religious_facilities
  if partial_lockdown? [ stop ]
  ;let gatherings_size 50
  repeat active_religious_facilities [
    let place_x 0
    let place_y 0
    ask one-of Religious_patches [ set place_x pxcor set place_y pycor]
    ask up-to-n-of Gathering_size persons with [ Age >= 19 and Age <= 74 and not Exit? and not aware_of_infection? ][ set xcor place_x - 1 + random(3) set ycor place_y - 1 + random(3) set Exit? true]
  ]
end


to go_back_home
  ask persons with [Exit?]
  [
    let random_x 0
    let random_y 0
    let person_id Id
    if  (one-of patches with [ Patch_ID = person_id ]) != nobody
    [
      ask one-of patches with [ Patch_ID = person_id ] [set random_x pxcor set random_y pycor]
      setxy random_x random_y
      set Exit? false
    ]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;   GO PROCEDURE   ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to go

  if ticks >= (Time * 24) [stop]

  ifelse prioritise_elderly?
  [
    foreach sort-on [(- Age)] Persons
    [
      patient -> ask patient [ check_health_state ]
    ]
  ]
  [
    ask Persons [ check_health_state ]
  ]

  ask Persons
  [
    if elapsed-day-hours > 6  [ infection_exposure ]
    ifelse not complete_lockdown? and elapsed-day-hours > 6 [ move 1 ][ move 0.1 ]
  ]

  ifelse elapsed-day-hours >= 24
  [
    set R0_global precision calculate_R0 2
    ;print cumulative_aware_of_infection
    set elapsed-day-hours 1
    set elapsed-week-days elapsed-week-days + 1
    set daily_new_cases 0
    set daily_new_deaths 0
  ]
  [
    if not complete_lockdown?
    [
      if elapsed-day-hours = 8 and elapsed-week-days mod 7 != 0
      [
        gather_in_kindergartens
        gather_in_primary_schools
        gather_in_middle_schools
        gather_in_secondary_schools
        gather_in_universities
        gather_in_government_facilities
        gather_in_health_facilities
        gather_in_commercial_facilities_1
      ]

      if elapsed-day-hours = 8 and elapsed-week-days mod 7 = 0
      [
        gather_in_cultural_facilities
        gather_in_religious_facilities
      ]

      if elapsed-day-hours = 14
      [
       go_back_home
      ]
      if elapsed-day-hours = 18 and elapsed-week-days mod 7 != 0
      [
        gather_in_commercial_facilities_2
        gather_in_cultural_facilities
      ]
      if elapsed-day-hours = 21
      [
       go_back_home
      ]
    ]
    set elapsed-day-hours elapsed-day-hours + 1
  ]

  if change_lockdown_condition? != complete_lockdown?
  [
    set change_lockdown_condition? complete_lockdown?
    go_back_home
  ]

  tick
end

to-report %infected
  ifelse any? Persons
    [ report precision ((count Persons with [infected?] / count Persons) * 100) 2 ]
    [ report 0 ]
end
@#$#@#$#@
GRAPHICS-WINDOW
408
231
1107
677
-1
-1
1.96
1
10
1
1
1
0
0
0
1
0
352
0
222
0
0
1
ticks
30.0

BUTTON
435
170
498
203
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
436
133
493
166
Region
display-Region
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

BUTTON
497
133
611
166
Neighborhoods
display-Neighborhoods
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

BUTTON
569
170
676
203
Pobulation_Blocks
display-Pobulation_Blocks
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

BUTTON
615
133
676
166
DEM
display-DEM
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

BUTTON
502
170
565
203
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

TEXTBOX
1183
120
1333
138
Medical parameters
11
0.0
1

SLIDER
1114
180
1332
213
average_days_for_contagion
average_days_for_contagion
0
100
4.0
1
1
Days
HORIZONTAL

TEXTBOX
1368
120
1518
138
Social interactions parameters
11
0.0
1

SLIDER
1346
180
1532
213
metres_per_patch
metres_per_patch
0
40
30.0
1
1
Meters
HORIZONTAL

SLIDER
901
181
1090
214
keep_social_distancing
keep_social_distancing
0
4
0.0
0.5
1
Meters
HORIZONTAL

SLIDER
1115
217
1333
250
maximum_contagion_distance
maximum_contagion_distance
0
3
2.0
0.5
1
Meters
HORIZONTAL

SLIDER
1115
254
1333
287
average_infection_length
average_infection_length
1
60
26.0
1
1
Days
HORIZONTAL

SLIDER
1115
291
1333
324
average-symptoms-show
average-symptoms-show
4
15
10.0
1
1
Days
HORIZONTAL

SLIDER
1116
328
1334
361
diagnosis_delay
diagnosis_delay
0
96
24.0
1
1
Hours
HORIZONTAL

SWITCH
707
143
895
176
prioritise_elderly?
prioritise_elderly?
1
1
-1000

SLIDER
1116
365
1334
398
chance_of_severe_infection
chance_of_severe_infection
0
100
18.5
0.5
1
%
HORIZONTAL

SLIDER
1116
402
1334
435
severity_death_chance_multiplier
severity_death_chance_multiplier
1
3
2.0
0.1
1
NIL
HORIZONTAL

SLIDER
1116
439
1335
472
medical_care_capacity
medical_care_capacity
0
100
100.0
1
1
Beds
HORIZONTAL

SWITCH
706
181
895
214
complete_lockdown?
complete_lockdown?
1
1
-1000

SWITCH
900
143
1089
176
partial_lockdown?
partial_lockdown?
1
1
-1000

TEXTBOX
5
66
208
94
Probability of infection by Age-group (%)
11
0.0
1

TEXTBOX
214
67
405
95
Probability of death by Age-group (%)
11
0.0
1

SLIDER
8
87
195
120
chance_of_infection_0-4
chance_of_infection_0-4
0
10
0.16
0.01
1
NIL
HORIZONTAL

SLIDER
8
124
195
157
chance_of_infection_5-9
chance_of_infection_5-9
0
10
0.07
0.01
1
NIL
HORIZONTAL

SLIDER
8
161
195
194
chance_of_infection_10-14
chance_of_infection_10-14
0
10
0.16
0.01
1
NIL
HORIZONTAL

SLIDER
8
198
195
231
chance_of_infection_15-19
chance_of_infection_15-19
0
10
0.26
0.01
1
NIL
HORIZONTAL

SLIDER
8
235
196
268
chance_of_infection_20-24
chance_of_infection_20-24
0
10
0.61
0.01
1
NIL
HORIZONTAL

SLIDER
8
272
196
305
chance_of_infection_25-29
chance_of_infection_25-29
0
10
0.72
0.01
1
NIL
HORIZONTAL

SLIDER
8
309
196
342
chance_of_infection_30-34
chance_of_infection_30-34
0
10
1.06
0.01
1
NIL
HORIZONTAL

SLIDER
8
346
196
379
chance_of_infection_35-39
chance_of_infection_35-39
0
10
1.82
0.01
1
NIL
HORIZONTAL

SLIDER
7
383
196
416
chance_of_infection_40-44
chance_of_infection_40-44
0
10
1.92
0.01
1
NIL
HORIZONTAL

SLIDER
7
420
197
453
chance_of_infection_45-49
chance_of_infection_45-49
0
10
1.89
0.01
1
NIL
HORIZONTAL

SLIDER
6
457
197
490
chance_of_infection_50-54
chance_of_infection_50-54
0
10
2.12
0.01
1
NIL
HORIZONTAL

SLIDER
6
493
198
526
chance_of_infection_55-59
chance_of_infection_55-59
0
10
2.55
0.01
1
NIL
HORIZONTAL

SLIDER
5
530
198
563
chance_of_infection_60-64
chance_of_infection_60-64
0
10
3.4
0.01
1
NIL
HORIZONTAL

SLIDER
5
567
198
600
chance_of_infection_65-69
chance_of_infection_65-69
0
10
3.57
0.01
1
NIL
HORIZONTAL

SLIDER
5
604
198
637
chance_of_infection_70-74
chance_of_infection_70-74
0
10
4.96
0.01
1
NIL
HORIZONTAL

SLIDER
5
641
197
674
chance_of_infection_75+
chance_of_infection_75+
0
10
6.44
0.01
1
NIL
HORIZONTAL

SLIDER
219
88
391
121
chance_of_death_0-4
chance_of_death_0-4
0
40
11.9
0.01
1
NIL
HORIZONTAL

SLIDER
219
125
391
158
chance_of_death_5-9
chance_of_death_5-9
0
40
5.26
0.01
1
NIL
HORIZONTAL

SLIDER
219
162
391
195
chance_of_death_10-14
chance_of_death_10-14
0
40
5.13
0.01
1
NIL
HORIZONTAL

SLIDER
219
199
391
232
chance_of_death_15-19
chance_of_death_15-19
0
40
3.33
0.01
1
NIL
HORIZONTAL

SLIDER
219
236
391
269
chance_of_death_20-24
chance_of_death_20-24
0
40
1.84
0.01
1
NIL
HORIZONTAL

SLIDER
219
273
392
306
chance_of_death_25-29
chance_of_death_25-29
0
40
1.18
0.01
1
NIL
HORIZONTAL

SLIDER
219
310
392
343
chance_of_death_30-34
chance_of_death_30-34
0
40
1.62
0.01
1
NIL
HORIZONTAL

SLIDER
219
347
393
380
chance_of_death_35-39
chance_of_death_35-39
0
40
2.47
0.01
1
NIL
HORIZONTAL

SLIDER
219
384
393
417
chance_of_death_40-44
chance_of_death_40-44
0
40
1.37
0.01
1
NIL
HORIZONTAL

SLIDER
219
421
393
454
chance_of_death_45-49
chance_of_death_45-49
0
40
2.04
0.01
1
NIL
HORIZONTAL

SLIDER
219
458
393
491
chance_of_death_50-54
chance_of_death_50-54
0
40
6.0
0.01
1
NIL
HORIZONTAL

SLIDER
219
495
393
528
chance_of_death_55-59
chance_of_death_55-59
0
40
10.64
0.01
1
NIL
HORIZONTAL

SLIDER
219
532
393
565
chance_of_death_60-64
chance_of_death_60-64
0
40
15.71
0.01
1
NIL
HORIZONTAL

SLIDER
219
569
393
602
chance_of_death_65-69
chance_of_death_65-69
0
40
18.7
0.01
1
NIL
HORIZONTAL

SLIDER
219
606
393
639
chance_of_death_70-74
chance_of_death_70-74
0
40
21.4
0.01
1
NIL
HORIZONTAL

SLIDER
219
643
393
676
chance_of_death_75+
chance_of_death_75+
0
40
30.91
0.01
1
NIL
HORIZONTAL

SLIDER
1114
143
1332
176
initial_infected_population
initial_infected_population
0
1
0.04
0.01
1
%
HORIZONTAL

SLIDER
1347
217
1533
250
active_kindergartens
active_kindergartens
0
68
68.0
1
1
NIL
HORIZONTAL

MONITOR
506
10
556
55
Days
ceiling (ticks / 24)
17
1
11

MONITOR
560
10
669
55
% Infected persons
%infected
17
1
11

MONITOR
788
10
904
55
# Untreated persons
count persons with [infected?] - count persons with [ontreatment?]
17
1
11

MONITOR
674
10
785
55
# Infected persons
count persons with [infected?]
17
1
11

MONITOR
478
60
528
105
R0
R0_global
17
1
11

MONITOR
532
60
648
105
# Recovered persons
count persons with [not infected? and gotinfection?]
17
1
11

MONITOR
651
60
757
105
Medical care used
medical_care_used
17
1
11

MONITOR
761
60
826
105
# Deaths
number_of_deaths
17
1
11

MONITOR
830
60
942
105
# Aware of infection
cumulative_aware_of_infection
17
1
11

SLIDER
1348
254
1533
287
active_primary_schools
active_primary_schools
0
82
82.0
1
1
NIL
HORIZONTAL

SLIDER
1348
291
1533
324
active_middle_schools
active_middle_schools
0
42
42.0
1
1
NIL
HORIZONTAL

SLIDER
1348
328
1532
361
active_secondary_schools
active_secondary_schools
0
73
73.0
1
1
NIL
HORIZONTAL

SLIDER
1349
365
1533
398
active_universities
active_universities
0
41
41.0
1
1
NIL
HORIZONTAL

SLIDER
1349
402
1533
435
active_commercial_facilities
active_commercial_facilities
0
241
241.0
1
1
NIL
HORIZONTAL

SLIDER
1350
439
1533
472
active_cultural_facilities
active_cultural_facilities
0
225
225.0
1
1
NIL
HORIZONTAL

SLIDER
1351
476
1534
509
active_government_facilities
active_government_facilities
0
461
461.0
1
1
NIL
HORIZONTAL

SLIDER
1351
513
1534
546
active_health_facilities
active_health_facilities
0
126
126.0
1
1
NIL
HORIZONTAL

SLIDER
1346
143
1532
176
Gathering_size
Gathering_size
0
50
50.0
1
1
NIL
HORIZONTAL

SLIDER
1351
550
1534
583
active_religious_facilities
active_religious_facilities
0
158
158.0
1
1
NIL
HORIZONTAL

TEXTBOX
837
116
987
135
Strategic Measures
15
124.0
1

TEXTBOX
34
28
310
53
The Agent-based model of COVID-19
17
95.0
1

PLOT
13
684
508
993
Epidemic curve
Days
Number of persons
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Infected persons" 1.0 0 -2674135 true "" "if ticks mod 24 = 0 [plot count persons with [infected?]]"
"Reported cases" 1.0 0 -8630108 true "" "if ticks mod 24 = 0 [plot cumulative_aware_of_infection]"
"Recovered persons" 1.0 0 -10899396 true "" "if ticks mod 24 = 0 [plot count persons with [not infected? and gotinfection?]]"
"Dead persons" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot number_of_deaths]"
"R0" 1.0 0 -11033397 true "" "if ticks mod 24 = 0 [plot R0_global]"

PLOT
513
684
1036
993
Infections per age group
Days
Number of persons
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"0-4" 1.0 0 -12895429 true "" "if ticks mod 24 = 0 [plot count persons with [Age <= 4 and gotinfection?]]"
"5-9" 1.0 0 -7500403 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 5 and Age <= 9 and gotinfection?]]"
"10-14" 1.0 0 -2674135 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 10 and Age <= 14 and gotinfection?]]"
"15-19" 1.0 0 -955883 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 15 and Age <= 19 and gotinfection?]]"
"20-24" 1.0 0 -6459832 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 20 and Age <= 24 and gotinfection?]]"
"25-29" 1.0 0 -1184463 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 25 and Age <= 29 and gotinfection?]]"
"30-34" 1.0 0 -10899396 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 30 and Age <= 34 and gotinfection?]]"
"35-39" 1.0 0 -13840069 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 35 and Age <= 39 and gotinfection?]]"
"40-44" 1.0 0 -14835848 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 40 and Age <= 44 and gotinfection?]]"
"45-49" 1.0 0 -11221820 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 45 and Age <= 49 and gotinfection?]]"
"50-54" 1.0 0 -13791810 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 50 and Age <= 54 and gotinfection?]]"
"55-59" 1.0 0 -13345367 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 55 and Age <= 59 and gotinfection?]]"
"60-64" 1.0 0 -8630108 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 60 and Age <= 64 and gotinfection?]]"
"65-69" 1.0 0 -5825686 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 65 and Age <= 69 and gotinfection?]]"
"70-74" 1.0 0 -2064490 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 70 and Age <= 74 and gotinfection?]]"
"75+" 1.0 0 -865067 true "" "if ticks mod 24 = 0 [plot count persons with [Age >= 75 and gotinfection?]]"

PLOT
1042
684
1539
993
Deaths per age group
Days
Number of persons
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"0-4" 1.0 0 -12895429 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_0_4]"
"5-9" 1.0 0 -7500403 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_5_9]"
"10-14" 1.0 0 -2674135 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_10_14]"
"15-19" 1.0 0 -955883 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_15_19]"
"20-24" 1.0 0 -6459832 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_20_24]"
"25-29" 1.0 0 -1184463 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_25_29]"
"30-34" 1.0 0 -10899396 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_30_34]"
"35-39" 1.0 0 -13840069 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_35_39]"
"40-44" 1.0 0 -14835848 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_40_44]"
"45-49" 1.0 0 -11221820 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_45_49]"
"50-54" 1.0 0 -13791810 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_50_54]"
"55-59" 1.0 0 -13345367 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_55_59]"
"60-64" 1.0 0 -8630108 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_60_64]"
"65-69" 1.0 0 -5825686 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_65_69]"
"70-74" 1.0 0 -2064490 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_70_74]"
"75+" 1.0 0 -865067 true "" "if ticks mod 24 = 0 [plot Deaths_by_age_75+]"

PLOT
13
998
764
1388
Neighbourhood_ID
Days
#Infected persons
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Neighbourhood_1" 1.0 1 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 1 and gotinfection? ]]"
"Neighbourhood_2" 1.0 0 -7500403 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 2 and gotinfection? ]]"
"Neighbourhood_3" 1.0 0 -2674135 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 3 and gotinfection? ]]"
"Neighbourhood_4" 1.0 0 -955883 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 4 and gotinfection? ]]"
"Neighbourhood_5" 1.0 0 -6459832 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 5 and gotinfection? ]]"
"Neighbourhood_6" 1.0 0 -1184463 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 6 and gotinfection? ]]"
"Neighbourhood_7" 1.0 0 -10899396 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 7 and gotinfection? ]]"
"Neighbourhood_8" 1.0 0 -13840069 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 8 and gotinfection? ]]"
"Neighbourhood_9" 1.0 0 -14835848 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 9 and gotinfection? ]]"
"Neighbourhood_10" 1.0 0 -11221820 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 10 and gotinfection? ]]"
"Neighbourhood_11" 1.0 0 -13791810 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 11 and gotinfection? ]]"
"Neighbourhood_12" 1.0 0 -13345367 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 12 and gotinfection? ]]"
"Neighbourhood_13" 1.0 0 -8630108 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 13 and gotinfection? ]]"
"Neighbourhood_14" 1.0 0 -5825686 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 14 and gotinfection? ]]"
"Neighbourhood_15" 1.0 0 -2064490 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 15 and gotinfection? ]]"
"Neighbourhood_16" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 16 and gotinfection? ]]"
"Neighbourhood_17" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 17 and gotinfection? ]]"
"Neighbourhood_18" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 18 and gotinfection? ]]"
"Neighbourhood_19" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 19 and gotinfection? ]]"
"Neighbourhood_20" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 20 and gotinfection? ]]"
"Neighbourhood_21" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 21 and gotinfection? ]]"
"Neighbourhood_22" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 22 and gotinfection? ]]"
"Neighbourhood_23" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 23 and gotinfection? ]]"
"Neighbourhood_24" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 24 and gotinfection? ]]"
"Neighbourhood_25" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 25 and gotinfection? ]]"
"Neighbourhood_26" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 26 and gotinfection? ]]"
"Neighbourhood_27" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 27 and gotinfection? ]]"
"Neighbourhood_28" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 28 and gotinfection? ]]"
"Neighbourhood_29" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 29 and gotinfection? ]]"
"Neighbourhood_30" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 30 and gotinfection? ]]"
"Neighbourhood_31" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 31 and gotinfection? ]]"
"Neighbourhood_32" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 32 and gotinfection? ]]"
"Neighbourhood_33" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 33 and gotinfection? ]]"
"Neighbourhood_34" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 34 and gotinfection? ]]"
"Neighbourhood_35" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 35 and gotinfection? ]]"
"Neighbourhood_36" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 36 and gotinfection? ]]"
"Neighbourhood_37" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 37 and gotinfection? ]]"
"Neighbourhood_38" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 38 and gotinfection? ]]"
"Neighbourhood_39" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 39 and gotinfection? ]]"
"Neighbourhood_40" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 40 and gotinfection? ]]"
"Neighbourhood_41" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 41 and gotinfection? ]]"
"Neighbourhood_42" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 42 and gotinfection? ]]"
"Neighbourhood_43" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 43 and gotinfection? ]]"
"Neighbourhood_44" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 44 and gotinfection? ]]"
"Neighbourhood_45" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 45 and gotinfection? ]]"
"Neighbourhood_46" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 46 and gotinfection? ]]"
"Neighbourhood_47" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 47 and gotinfection? ]]"
"Neighbourhood_48" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 48 and gotinfection? ]]"
"Neighbourhood_49" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 49 and gotinfection? ]]"
"Neighbourhood_50" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 50 and gotinfection? ]]"
"Neighbourhood_51" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 51 and gotinfection? ]]"
"Neighbourhood_52" 1.0 0 -16777216 true "" "if ticks mod 24 = 0 [plot count Persons with [ Neighbourhood_ID = 52 and gotinfection? ]]"

MONITOR
922
10
1021
55
Risk of residential
Risk_of_Residential
17
1
11

MONITOR
1025
10
1129
55
Risk of educational
Risk_of_Educational
17
1
11

MONITOR
1133
10
1235
55
Risk of commercial
Risk_of_Commercial
17
1
11

MONITOR
1239
10
1321
55
Risk of cultural
Risk_of_Cultural
17
1
11

MONITOR
974
60
1079
105
Risk of government
Risk_of_Government
17
1
11

MONITOR
1082
60
1164
105
Risk of health
Risk_of_Health
17
1
11

MONITOR
1167
60
1257
105
Risk of religious
Risk_of_Religious
17
1
11

INPUTBOX
408
48
468
108
Time
100.0
1
0
Number

TEXTBOX
384
10
505
38
Change time to run a longer or shorter time period
11
85.0
1

PLOT
768
998
1192
1235
Daily new cases & deaths
Days
Number of persons
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Daily new cases" 1.0 0 -5298144 true "" "if ticks mod 24 = 0 [plot daily_new_cases]\n\n"
"Daily new deaths" 1.0 0 -16383231 true "" "if ticks mod 24 = 0 [plot daily_new_deaths]"

@#$#@#$#@
## WHAT IS IT?

The model presented here is an agent-based model (ABM) by integrating with an improved SASOARD (susceptible-asymptomatic-symptomatic-on treatment-aggravated infection-recovered-dead) model in the geographical information system (GIS) framework to simulate the spatio-temporal spread of COVID-19. This model is designed based on demographic data, different types of land uses, and the heterogeneous interactions within the community to track the spatial location of agents, their mobility, and the spatial spread of the disease. In this model, the effects of various intervention scenarios, including complete lock-down, partial lockdown, social distancing, restriction on social gatherings, and vaccination are evaluated. The proposed model can serve as a valuable tool to assist health policymakers in better understand the spatio-temporal spread of various strains of COVID-19 and evaluate the effective preventive measures. Moreover, the proposed ABM with GIS integration can be used as a spatial decision-support tool to promote the resilience and sustainability of urban systems against future outbreaks.

## DESCRIPTION OF THE MODEL

The proposed model consists of two types of agents: human agents and cell agents. Each human agent has different characteristics and behaviors, and their likelihood of contracting or dying from COVID-19 varies based on their age group. The cell agents represent different land uses in the studied area. The model assumes that COVID-19 is transmitted only between human agents and ignores the transmission of the disease in closed environments (e.g., through contaminated surfaces). A time step of one hour is considered in the model to account for transmission occurring at any time of the day. Therefore, the proposed model can depict various interactions between human and cell agents in different time steps.


## HOW IT WORKS

At the start of each time step, the model counter is updated, and the demographic and spatial data of the study area are assigned to the environment (cell agents). Then, human agents are assigned to the population blocks based on demographic information. In other words, to allocate the real population to each population block in the study area, demographic information based on 16 age groups was assigned to each of the 1911 corresponding population blocks in the study area. Accordingly, at the beginning of the modeling, each of the 1911 population blocks has a specific number of human agents in each of the 16 age groups. The characteristics of human agents are determined randomly, such as the infection period (TI), which is calculated randomly based on the normal probability density function (N(26,5) days). Human agents can experience different epidemic states such as susceptible, asymptomatic infected, symptomatic infected, etc. They can perform various activities according to their age groups at certain times of the day by moving toward different land uses during the day. For example, people in the age group of 12 to 14 years attend middle schools (educational land use) at 8 am and return to their population blocks at 2 pm. Human agents can have varying reactions to different events based on their conditions. For instance, an individual with an aggravated infection who is not treated will have an increased probability of death.
In contrast, cell agents do not move and can be any of the land uses in the studied area. Since Gorgan city occupies an almost rectangular area of 10,590 meters in length and 6,690 meters in width, and each cell agent is 30 meters by 30 meters, there are 78,719 cell agents (223*353) in the model. To model the spatial spread of COVID-19, a susceptibility value is assigned for each cell agent. If a susceptible human is in close proximity to an infected human, based on a certain probability and the distance from the infected human, the susceptible human can contract the disease and enter the asymptomatic stage. Then, the cell agent in which the susceptible human is located will increase its susceptibility by one unit in response. In each time step, the number of cases and deaths and the basic reproductive number (R0) are updated. Based on the UML sequence diagram, all agents repeat their activities in each time step. Also, each process in the model is activated under certain conditions. For example, if an infected human enters the acute stage of the disease and is unable to recover, the death process will be activated for that agent.

## HOW TO USE IT

After adjusting the parameters of the models, simply click the setup button and click go. The model will continue to run.

## THINGS TO NOTICE

You can watch the model space and mobile agents moving throughout it to see how the disease spreads throughout the study area. The model has five plot outputs. The first shows the number of infected, reported, recovered, and dead persons and the R0 through time. The second and third plot illustrates the number of infections and deaths per age group over time, respectively. The fourth plot shows the number of infected persons in each neighborhood over time. The fifth plot shows the daily new cases and deaths.


## EXTENDING THE MODEL

If you have any suggestions for things to add or change in the model feel free to contact me at mtabasi@mail.kntu.ac.ir. I (Mohammad Tabasi) am not an epidemiologist, so if there are epidemiologists out there who feel the model needs drastic improvement, please contact me.


## CREDITS AND REFERENCES

This model developed by Mohammad Tabasi at the department of GIS, Faculty of Geodesy and Geomatics Engineering, K. N. Toosi University of Technology, Tehran, Iran.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
